@@ -1,4 +1,4 @@
-void PeakSegPDPALog
+int PeakSegPDPALog
 (int *data_vec, double *weight_vec, int data_count,
  int maxSegments,
  // the following matrices are for output, data_count x maxSegments.
